# klez-tools

A simple tool to encode names using numeric cryptography logic.

## Installation

To install, use pip:

```
pip install klez-tools
```

## Usage

To use the tool, run:

```
klez-tools
```
